package v1

import (
	"designs/app/common/request"
	"designs/app/common/response"
	"designs/common"
	"designs/config"
	"designs/global"
	"errors"
	"fmt"
	"time"

	"github.com/gin-gonic/gin"
)

type GameConfig struct {
	Gid       string `form:"gid" json:"gid" binding:"required"`             //游戏id
	GameName  string `form:"gameName" json:"gameName" binding:"required"`   //游戏名称
	WxAppid   string `form:"wxAppid" json:"wxAppid" binding:"required"`     //微信appid
	WxSecret  string `form:"wxSecret" json:"wxSecret" binding:"required"`   //微信secret
	TtAppid   string `form:"ttAppid" json:"ttAppid" binding:"required"`     //抖音appid
	TtSecret  string `form:"ttSecret" json:"ttSecret" binding:"required"`   //抖音secret
	AppSecret string `form:"appSecret" json:"appSecret" binding:"required"` //游戏配置密钥
}

type GetGameCfg struct {
	AppSecret string `form:"appSecret" json:"appSecret" binding:"required"` //游戏配置密钥
}

/* code 结构体 */
type CodeData struct {
	Code string `form:"code" json:"code" binding:"required"`
	Gid  string `form:"gid" json:"gid" binding:"required"`
	Pf   string `form:"pf" json:"pf" binding:"required"`
}

/* 保存数据结构体 */
type SaveData struct {
	Extend string `form:"extend" json:"extend" binding:"required"`
	Data   string `form:"data" json:"data" binding:"required"`
	Secret string `form:"secret" json:"secret" binding:""`
}

/* 获取结构体 */
type GetSaveData struct {
	Extend string `form:"extend" json:"extend" binding:"required"`
}

/*
*登陆
 */
func Login(c *gin.Context) {
	//http://127.0.0.1:8787/v1/user/login
	// 使用 ShouldBind 方法自动绑定：
	form := request.Check(c, &struct {
		UserName string `form:"userName" json:"userName" binding:"required"`
		Password string `form:"password" json:"password" binding:"required"`
	}{})

	//验证
	adminUser := config.Get("app.admin_user")
	adminSecret := config.Get("app.admin_secret")

	if form.UserName != adminUser || form.Password != adminSecret {
		response.Fail(c, 1000, errors.New("账号密码错误"))
	}

	//获取token
	token, err := common.GetJwtToken(form.UserName, 0)
	//刷新refreshtoken
	refresh, _ := common.GetJwtToken(form.UserName, 1)
	if err != nil {
		response.Fail(c, 1003, err.Error())
		return
	}

	//回传
	response.Success(c, gin.H{
		"token":        token,
		"refreshToken": refresh,
		"loginTime":    time.Now().Unix(),
		"ip":           c.ClientIP(),
	})
}

/* 刷新token */
func RefreshToken(c *gin.Context) {
	userName := c.GetString("userName")

	//获取token
	token, err0 := common.GetJwtToken(userName, 0)
	if err0 != nil {
		global.App.Log.Info("RefreshToken err")
		common.RetJson(1003, "RefreshToken err", "", c)
		return
	}

	data := map[string]interface{}{
		"token": token,
	}
	//返回数据
	common.RetJson(0, "success", data, c)
}

/* 获取时间 */
func GetSysTime(c *gin.Context) {
	time := time.Now().Unix()
	common.RetJson(0, "获取系统时间", time, c)
}

func UserList(c *gin.Context) {
	form := request.Check(c, &struct {
		Offset int `form:"offset" json:"offset" binding:""`
		Limit  int `form:"limit" json:"limit" binding:"required"`
	}{})

	fmt.Print(form)
}
